attitude

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 25, 2013 License: AGPL-3.0, AGPL-3.0-or-later Imports: 4 Imported by: 6

Documentation

Overview

Package attitude contains algorithm for determining the drones position relative to the ground.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Attitude added in v0.1.0

type Attitude struct {
	Roll     float64 // degree
	Pitch    float64 // degree
	Yaw      float64 // degree
	Altitude float64 // meters
}

Attitude describes the drones position relative to the ground.

func (Attitude) String added in v0.1.0

func (d Attitude) String() string

String returns a human readable version of the Attitude.

type Complementary

type Complementary struct {
	// contains filtered or unexported fields
}

Implements a simple complementation filter. see http://www.pieter-jan.com/node/11

func NewComplementary

func NewComplementary() *Complementary

NewComplementary returns a new Complementary filter.

func (*Complementary) Update

func (c *Complementary) Update(d imu.Data) Attitude

Update processes the given imu.Data and returns the new Attitude.

Jump to