Documentation
¶
Overview ¶
Package attitude contains algorithm for determining the drones position relative to the ground.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Attitude ¶ added in v0.1.0
type Attitude struct {
Roll float64 // degree
Pitch float64 // degree
Yaw float64 // degree
Altitude float64 // meters
}
Attitude describes the drones position relative to the ground.
type Complementary ¶
type Complementary struct {
// contains filtered or unexported fields
}
Implements a simple complementation filter. see http://www.pieter-jan.com/node/11
func NewComplementary ¶
func NewComplementary() *Complementary
NewComplementary returns a new Complementary filter.
Click to show internal directories.
Click to hide internal directories.